AprsWeather

Struct AprsWeather 

pub struct AprsWeather {
    pub wind_direction: Option<u16>,
    pub wind_speed: Option<u16>,
    pub wind_gust: Option<u16>,
    pub temperature: Option<i16>,
    pub rain_1h: Option<u16>,
    pub rain_24h: Option<u16>,
    pub rain_since_midnight: Option<u16>,
    pub humidity: Option<u8>,
    pub pressure: Option<u32>,
}
An APRS weather report.

Weather data can be embedded in a position report or sent as a standalone positionless weather report (data type _). The TH-D75 displays weather station data in the station list.

All fields are optional — weather stations may report any subset.

Fields

wind_direction: Option<u16>

Wind direction in degrees (0-360).

wind_speed: Option<u16>

Wind speed in mph.

wind_gust: Option<u16>

Wind gust in mph (peak in last 5 minutes).

temperature: Option<i16>

Temperature in degrees Fahrenheit.

rain_1h: Option<u16>

Rainfall in last hour (hundredths of an inch).

rain_24h: Option<u16>

Rainfall in last 24 hours (hundredths of an inch).

rain_since_midnight: Option<u16>

Rainfall since midnight (hundredths of an inch).

humidity: Option<u8>

Humidity in percent (1-100). Raw APRS 00 is converted to 100.

pressure: Option<u32>

Barometric pressure in tenths of millibars/hPa.