ModemStatus

Struct ModemStatus 

pub struct ModemStatus {
    pub mode: ModemMode,
    pub flags: StatusFlags,
    pub dstar_space: u8,
    pub dmr_space1: u8,
    pub dmr_space2: u8,
    pub ysf_space: u8,
    pub p25_space: u8,
    pub nxdn_space: u8,
    pub pocsag_space: u8,
    pub fm_space: u8,
}
Parsed modem status response.

Fields

mode: ModemMode

Current modem mode.

flags: StatusFlags

Status flags (TX, overflow bits, lockout, CD).

dstar_space: u8

D-STAR TX FIFO slots free.

dmr_space1: u8

DMR slot-1 TX FIFO slots free.

dmr_space2: u8

DMR slot-2 TX FIFO slots free.

ysf_space: u8

YSF TX FIFO slots free.

p25_space: u8

P25 TX FIFO slots free.

nxdn_space: u8

NXDN TX FIFO slots free.

pocsag_space: u8

POCSAG TX FIFO slots free.

fm_space: u8

FM TX FIFO slots free (0 on protocol v1).

Implementations



impl ModemStatus

pub const fn tx(&self) -> bool

TX active (delegates to [StatusFlags::tx]).

pub const fn adc_overflow(&self) -> bool

ADC input level overflowed.

pub const fn rx_overflow(&self) -> bool

RX buffer overflowed.

pub const fn tx_overflow(&self) -> bool

TX buffer overflowed.

pub const fn lockout(&self) -> bool

Carrier-sense lockout active.

pub const fn dac_overflow(&self) -> bool

DAC output level overflowed.

pub const fn cd(&self) -> bool

Carrier detected.

pub fn parse_v1(payload: &[u8]) -> Result<ModemStatus, MmdvmError>

Parse a protocol-v1 status response payload.

Errors

Returns MmdvmError::InvalidStatusLength if the payload is shorter than the minimum v1 layout requires.

pub fn parse_v2(payload: &[u8]) -> Result<ModemStatus, MmdvmError>

Parse a protocol-v2 status response payload.

Errors

Returns MmdvmError::InvalidStatusLength if the payload is shorter than the minimum v2 layout requires.